﻿using SoapEndpoint.Service.Flows.Inventarisatie.v1.LogbookService;
using SoapEndpoint.Service.Proxy.Models.Systeem;
using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v2.ErrorMessage;
using SoapEndpoint.Tester.Scenario.Flow.Inventarisatie;

namespace SoapEndpoint.Tester.Scenario.Implementations.Inventarisatie;

public class SeSectorZorgScenario : InventarisatieScenarioBase
{
    public override string Name => "SE Sector Zorg scenario";

    public override AdresboekOrganisatieModel SeOrganization =>
        Manager.Organizations.SingleOrDefault(p => p.Referentienummer.ToString()
            .Equals(Program.Configuration["SeHealthCareTestOrganizationReference"],
                StringComparison.CurrentCultureIgnoreCase));

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Happy flow - Regeling geaccordeerd 1");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_SaldoverzoekZorg, BerichtType.SE_SaldoverzoekAntwoord));

        await SendInvalidSaldoverzoek();
    }

    private async Task SendInvalidSaldoverzoek()
    {
        var messageTypes = new List<BerichtType>
        {
            BerichtType.SHV_Saldoverzoek,
            BerichtType.SHV_SaldoverzoekNuts,
            BerichtType.SHV_SaldoverzoekPubliek
        };

        foreach (var messageType in messageTypes)
        {
            StartNewScenario($"Foutsituatie: {messageType}");

            await Manager.SHV_SendIncorrectMessageAsync(Conversation, messageType, null,
                ShvKnooppuntFoutcode.Incorrectberichttypevoorsectorvanontvanger);
        }
    }
}