﻿using System.Text;
using SoapEndpoint.Service.Flows.SbEnSk.v1.LogbookService;
using SoapEndpoint.Service.Proxy.Models.Systeem;
using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v2.ErrorMessage;
using SoapEndpoint.Tester.Scenario.Flow.SbEnSk;

namespace SoapEndpoint.Tester.Scenario.Implementations.SbEnSk;

public class ToestemmingsverklaringScenario : SbEnSkScenarioBase
{
    public override string Name => "Toestemmingsverklaring scenario";

    public override AdresboekOrganisatieModel ShvOrganization =>
        Manager.Organizations.SingleOrDefault(p => p.Referentienummer.ToString()
            .Equals(Program.Configuration["ShvRequiresStatementOfConsentTestOrganizationReference"],
                StringComparison.CurrentCultureIgnoreCase));

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Kennisgeving met bijlage");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_Kennisgeving, BerichtType.SE_KennisgevingAntwoord, true),
            new ShvFlowItem(BerichtType.SHV_Saldoverzoek, BerichtType.SE_SaldoverzoekAntwoord, true));

        StartNewScenario("Saldoverzoek met bijlage");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_Saldoverzoek, BerichtType.SE_SaldoverzoekAntwoord, true));

        StartNewScenario("Zonder bijlage");

        await Manager.SHV_SendIncorrectMessageAsync(Conversation, BerichtType.SHV_Kennisgeving, null,
            ShvKnooppuntFoutcode.Bijlageverplichtvoorbericht);

        await Manager.SHV_SendIncorrectMessageAsync(Conversation, BerichtType.SHV_Saldoverzoek, null,
            ShvKnooppuntFoutcode.Bijlageverplichtvoorbericht);

        StartNewScenario("Invalide base64 data");

        var bijlage = new BijlageModel
        {
            Data = Encoding.ASCII.GetBytes("test123")
        };
        await Manager.SHV_SendIncorrectMessageAsync(Conversation, BerichtType.SHV_Saldoverzoek, null,
            new List<BijlageModel> { bijlage }, ShvKnooppuntFoutcode.BijlagedataisinvalideBase64);

        StartNewScenario("Invalide bestandsformaat");

        bijlage = new BijlageModel
        {
            Data = Encoding.ASCII.GetBytes("dGVzdA==")
        };
        await Manager.SHV_SendIncorrectMessageAsync(Conversation, BerichtType.SHV_Saldoverzoek, null,
            new List<BijlageModel> { bijlage }, ShvKnooppuntFoutcode.Bijlagenietinjuisteformaat);
    }
}