﻿using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v1.ErrorMessage;
using SoapEndpoint.Service.Systeem.v1.LogbookService;
using SoapEndpoint.Tester.Scenario.Flow.Schuldbemiddeling;

namespace SoapEndpoint.Tester.Scenario.Implementations.Schuldbemiddeling;

public class CollectiefSchuldregelenScenario : SchuldbemiddelingScenarioBase
{
    public override string Name => "Collectief schuldregelen scenario";

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Incorrect betaalvoorstel");

        // Send saldo verzoek and reply saldo verzoek antwoord
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek,
                Berichttype.SE_SaldoverzoekAntwoordStandaardAkkoord));

        // Send betaalvoorstel (not allowed)
        await Manager.SHV_SendMessageAsync(Conversation, Berichttype.SHV_Betaalvoorstel);

        // Check that the correct error is returned.
        await Manager.SHV_GetAndConfirmErrorMessage<ShvKnooppuntFoutbericht, Berichttype, ShvKnooppuntFoutcode>(
            Conversation,
            Berichttype.SYS_FoutBericht,
            ShvKnooppuntFoutcode.Berichttypeniettoegestaanvoordehuidigestaatvandeconversatie);

        StartNewScenario("Saldoverzoek antwoord flow");

        // Happy flow schuldregeling geaccordeerd
        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoord),
            new ShvFlowItem(Berichttype.SHV_Betaalvoorstel, Berichttype.SE_BetaalvoorstelAntwoord),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingGeaccordeerd));

        StartNewScenario("Happyflow schuldregeling geaccordeerd");

        // Happy flow schuldregeling geaccordeerd
        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoordStandaardAkkoord),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingGeaccordeerd));

        StartNewScenario("Happyflow schuldregeling beeindigd");

        // Happy flow schuldregeling beeindigd
        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoordStandaardAkkoord),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingBeeindigd));
    }
}