﻿using System.Xml;
using System.Xml.Linq;

namespace Infrastructure.Utils.Xml;

public static class XmlExtensions
{
    public static XElement ToXElement(this XmlNode node)
    {
        var xDoc = new XDocument();
        using (var xmlWriter = xDoc.CreateWriter())
        {
            node.WriteTo(xmlWriter);
        }

        return xDoc.Root;
    }

    public static XmlDocument ToXmlDocument(this XNode node)
    {
        using var xmlReader = node.CreateReader();
        var xmlDoc = new XmlDocument();
        xmlDoc.Load(xmlReader);
        return xmlDoc;
    }

    public static XmlElement ToXmlNode(this XElement element) => element.ToXmlDocument().DocumentElement;

    public static void ClearChildren(this XmlNode node)
    {
        foreach (var child in node.ChildNodes.Cast<XmlNode>().ToArray()) node.RemoveChild(child);
    }

    public static void AddChildren(this XmlNode node, IEnumerable<XmlNode> children)
    {
        foreach (var child in children) node.AppendChild(child);
    }
}