﻿namespace SoapEndpoint.Service.Proxy.Infrastructure;

public class SystemVersions
{
    public static Version?[] AllVersions { get; } = typeof(SystemVersions).GetProperties()
        .Where(p => typeof(Version).IsAssignableFrom(p.PropertyType) && p.Name.StartsWith("V"))
        .Select(p => p.GetValue(null))
        .Cast<Version>()
        .ToArray();

    public static Version[] MajorVersions { get; } = AllVersions.Where(v => v.Minor == 0).ToArray();

    public static Version V1_0 => new("1.0");
    public static Version V2_0 => new("2.0");

    public static Version? DefaultVersion(string? defaultVersion) => GetByVersion(defaultVersion);

    public static Version? GetByVersion(string? version)
    {
        return version is null ? null : Array.Find(AllVersions, e => e?.ToString() == version);
    }
}